# Calendar.social
# Copyright (C) 2018  Gergely Polonkai
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""Helper functions and fixtures for testing
"""

import pytest

import calsocial
from calsocial.models import db


def configure_app():
    """Set default configuration values for testing
    """

    calsocial.app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite:///'
    calsocial.app.config['TESTING'] = True
    calsocial.app.config['WTF_CSRF_ENABLED'] = False


@pytest.fixture
def client():
    """Fixture that provides a Flask test client
    """
    configure_app()
    client = calsocial.app.test_client()

    with calsocial.app.app_context():
        db.create_all()

    yield client

    with calsocial.app.app_context():
        db.drop_all()


def login(client, username, password, no_redirect=False):
    """Login with the specified username and password
    """

    return client.post('/login',
                       data={'email': username, 'password': password},
                       follow_redirects=not no_redirect)


@pytest.fixture
def database():
    """Fixture to provide all database tables in an active application context
    """

    configure_app()

    with calsocial.app.app_context():
        db.create_all()

        yield db

        db.drop_all()
